@@ -185,9 +185,9 @@ impl io::Write for RollingFileAppender {
         let now = OffsetDateTime::now_utc().to_offset(self.offset);
         let writer = self.writer.get_mut();
         if self.state.should_rollover(now) {
+            self.state.refresh_writer(now, writer);
             let _did_cas = self.state.advance_date(now);
             debug_assert!(_did_cas, "if we have &mut access to the appender, no other thread can have advanced the timestamp...");
-            self.state.refresh_writer(now, writer);
         }
         writer.write(buf)
     }
@@ -529,14 +529,17 @@ impl Inner {
             .next_date(&now)
             .map(|date| date.unix_timestamp() as usize)
             .unwrap_or(0);
-        self.next_date
-            .compare_exchange(
-                now.unix_timestamp() as usize,
-                next_date,
-                Ordering::AcqRel,
-                Ordering::Acquire,
-            )
-            .is_ok()
+
+        self.next_date.store(next_date, Ordering::Release);
+            // .compare_exchange(
+            //     now.unix_timestamp() as usize,
+            //     next_date,
+            //     Ordering::AcqRel,
+            //     Ordering::Acquire,
+            // )
+            // .is_ok()
+
+        true
     }
 }
 
